#!/bin/bash

START_SH_PATH="$(dirname $(realpath $0))"
BASE_PATH=$START_SH_PATH
REGION_CONF_FILE=/etc/ed_gwl/region
REGION_DEFAULT=US915

function get_region(){
    local region_file="$REGION_CONF_FILE"
    local region_default="$REGION_DEFAULT"
    local region=

    if [ -f "$region_file" ]; then
        region=$(sed -n "1p" $region_file)
    else
        region="$region_default"
    fi

    echo "$region"
}

function update_config(){
    GWID_BEGINFIX="fffe"
    GWID_MID=$(ip link show eth0 | awk '/ether/ {print $2}' | awk -F\: '{print $1$2$3}')
    GWID_END=$(ip link show eth0 | awk '/ether/ {print $2}' | awk -F\: '{print $4$5$6}')

    sed -i 's/\(^\s*"gateway_ID":\s*"\).\{16\}"\s*\(,\?\).*$/\1'${GWID_BEGINFIX}${GWID_MID}${GWID_END}'"\2/' $1
    sed -i 's/\(^\s*"serv_port_up":\s*\).\d*\s*\(,\?\).*$/\11700,/' $1
    sed -i 's/\(^\s*"serv_port_down":\s*\).\d*\s*\(,\?\).*$/\11700,/' $1
}

function start_pktfwd() {
    local base_path="$BASE_PATH"
    local pktfwd="$base_path/lora_pkt_fwd"
    local region=$(get_region)
    local conf_filename="global_conf.json.sx1250.$region"
    local conf_preset="$base_path/conf/$conf_filename"
    local conf_default="$base_path/conf/global_conf.json.sx1250.$REGION_DEFAULT"    
    local conf="$base_path/conf/global_conf.json.$region"

    if [ ! -f "$conf" ]; then
        if [ -f "$conf_preset" ]; then
            # conf="$conf_preset"
            cp $conf_preset $conf
        else
            # conf="$conf_default"
            cp $conf_default $conf
        fi
        update_config $conf
    fi

    echo "$(date '+%Y-%m-%d %H:%M:%S') [info] pktfwd: started with conf file: $conf"
    $pktfwd -c $conf
}


start_pktfwd
